Class: Google::Apis::TagmanagerV1::ContainerVersionHeader
- Inherits:
-
Object
- Object
- Google::Apis::TagmanagerV1::ContainerVersionHeader
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tagmanager_v1/classes.rb,
lib/google/apis/tagmanager_v1/representations.rb,
lib/google/apis/tagmanager_v1/representations.rb
Overview
Represents a Google Tag Manager Container Version Header.
Instance Attribute Summary collapse
-
#account_id ⇒ String
GTM Account ID.
-
#container_id ⇒ String
GTM Container ID.
-
#container_version_id ⇒ String
The Container Version ID uniquely identifies the GTM Container Version.
-
#deleted ⇒ Boolean
(also: #deleted?)
A value of true indicates this container version has been deleted.
-
#name ⇒ String
Container version display name.
-
#num_tags ⇒ String
Number of tags in the container version.
-
#num_triggers ⇒ String
Number of triggers in the container version.
-
#num_variables ⇒ String
Number of variables in the container version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContainerVersionHeader
constructor
A new instance of ContainerVersionHeader.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContainerVersionHeader
Returns a new instance of ContainerVersionHeader.
359 360 361 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 359 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ String
GTM Account ID.
Corresponds to the JSON property accountId
321 322 323 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 321 def account_id @account_id end |
#container_id ⇒ String
GTM Container ID.
Corresponds to the JSON property containerId
326 327 328 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 326 def container_id @container_id end |
#container_version_id ⇒ String
The Container Version ID uniquely identifies the GTM Container Version.
Corresponds to the JSON property containerVersionId
331 332 333 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 331 def container_version_id @container_version_id end |
#deleted ⇒ Boolean Also known as: deleted?
A value of true indicates this container version has been deleted.
Corresponds to the JSON property deleted
336 337 338 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 336 def deleted @deleted end |
#name ⇒ String
Container version display name.
Corresponds to the JSON property name
342 343 344 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 342 def name @name end |
#num_tags ⇒ String
Number of tags in the container version.
Corresponds to the JSON property numTags
347 348 349 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 347 def @num_tags end |
#num_triggers ⇒ String
Number of triggers in the container version.
Corresponds to the JSON property numTriggers
352 353 354 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 352 def num_triggers @num_triggers end |
#num_variables ⇒ String
Number of variables in the container version.
Corresponds to the JSON property numVariables
357 358 359 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 357 def num_variables @num_variables end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
364 365 366 367 368 369 370 371 372 373 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 364 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @container_id = args[:container_id] if args.key?(:container_id) @container_version_id = args[:container_version_id] if args.key?(:container_version_id) @deleted = args[:deleted] if args.key?(:deleted) @name = args[:name] if args.key?(:name) @num_tags = args[:num_tags] if args.key?(:num_tags) @num_triggers = args[:num_triggers] if args.key?(:num_triggers) @num_variables = args[:num_variables] if args.key?(:num_variables) end |