Class: Google::Apis::TagmanagerV1::CreateContainerVersionRequestVersionOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tagmanager_v1/classes.rb,
lib/google/apis/tagmanager_v1/representations.rb,
lib/google/apis/tagmanager_v1/representations.rb

Overview

Options for new container versions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateContainerVersionRequestVersionOptions

Returns a new instance of CreateContainerVersionRequestVersionOptions.



396
397
398
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 396

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The name of the container version to be created. Corresponds to the JSON property name

Returns:

  • (String)


383
384
385
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 383

def name
  @name
end

#notesString

The notes of the container version to be created. Corresponds to the JSON property notes

Returns:

  • (String)


388
389
390
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 388

def notes
  @notes
end

#quick_previewBoolean Also known as: quick_preview?

The creation of this version may be for quick preview and shouldn't be saved. Corresponds to the JSON property quickPreview

Returns:

  • (Boolean)


393
394
395
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 393

def quick_preview
  @quick_preview
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



401
402
403
404
405
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 401

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @notes = args[:notes] if args.key?(:notes)
  @quick_preview = args[:quick_preview] if args.key?(:quick_preview)
end