Class: Google::Apis::TagmanagerV1::Environment
- Inherits:
-
Object
- Object
- Google::Apis::TagmanagerV1::Environment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tagmanager_v1/classes.rb,
lib/google/apis/tagmanager_v1/representations.rb,
lib/google/apis/tagmanager_v1/representations.rb
Overview
Represents a Google Tag Manager Environment. Note that a user can create, delete and update environments of type USER, but can only update the enable_debug and url fields of environments of other types.
Instance Attribute Summary collapse
-
#account_id ⇒ String
GTM Account ID.
-
#authorization_code ⇒ String
The environment authorization code.
-
#authorization_timestamp_ms ⇒ Fixnum
The last update time-stamp for the authorization code.
-
#container_id ⇒ String
GTM Container ID.
-
#container_version_id ⇒ String
Corresponds to the JSON property
containerVersionId. -
#description ⇒ String
The environment description.
-
#enable_debug ⇒ Boolean
(also: #enable_debug?)
Whether or not to enable debug by default on for the environment.
-
#environment_id ⇒ String
GTM Environment ID uniquely identifies the GTM Environment.
-
#fingerprint ⇒ String
The fingerprint of the GTM environment as computed at storage time.
-
#name ⇒ String
The environment display name.
-
#type ⇒ String
The type of this environment.
-
#url ⇒ String
Default preview page url for the environment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Environment
constructor
A new instance of Environment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Environment
Returns a new instance of Environment.
504 505 506 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 504 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ String
GTM Account ID.
Corresponds to the JSON property accountId
443 444 445 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 443 def account_id @account_id end |
#authorization_code ⇒ String
The environment authorization code.
Corresponds to the JSON property authorizationCode
448 449 450 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 448 def @authorization_code end |
#authorization_timestamp_ms ⇒ Fixnum
The last update time-stamp for the authorization code.
Corresponds to the JSON property authorizationTimestampMs
453 454 455 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 453 def @authorization_timestamp_ms end |
#container_id ⇒ String
GTM Container ID.
Corresponds to the JSON property containerId
458 459 460 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 458 def container_id @container_id end |
#container_version_id ⇒ String
Corresponds to the JSON property containerVersionId
463 464 465 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 463 def container_version_id @container_version_id end |
#description ⇒ String
The environment description. Can be set or changed only on USER type
environments.
Corresponds to the JSON property description
469 470 471 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 469 def description @description end |
#enable_debug ⇒ Boolean Also known as: enable_debug?
Whether or not to enable debug by default on for the environment.
Corresponds to the JSON property enableDebug
474 475 476 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 474 def enable_debug @enable_debug end |
#environment_id ⇒ String
GTM Environment ID uniquely identifies the GTM Environment.
Corresponds to the JSON property environmentId
480 481 482 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 480 def environment_id @environment_id end |
#fingerprint ⇒ String
The fingerprint of the GTM environment as computed at storage time. This value
is recomputed whenever the environment is modified.
Corresponds to the JSON property fingerprint
486 487 488 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 486 def fingerprint @fingerprint end |
#name ⇒ String
The environment display name. Can be set or changed only on USER type
environments.
Corresponds to the JSON property name
492 493 494 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 492 def name @name end |
#type ⇒ String
The type of this environment.
Corresponds to the JSON property type
497 498 499 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 497 def type @type end |
#url ⇒ String
Default preview page url for the environment.
Corresponds to the JSON property url
502 503 504 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 502 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
509 510 511 512 513 514 515 516 517 518 519 520 521 522 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 509 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @authorization_code = args[:authorization_code] if args.key?(:authorization_code) @authorization_timestamp_ms = args[:authorization_timestamp_ms] if args.key?(:authorization_timestamp_ms) @container_id = args[:container_id] if args.key?(:container_id) @container_version_id = args[:container_version_id] if args.key?(:container_version_id) @description = args[:description] if args.key?(:description) @enable_debug = args[:enable_debug] if args.key?(:enable_debug) @environment_id = args[:environment_id] if args.key?(:environment_id) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) @url = args[:url] if args.key?(:url) end |