Class: Google::Apis::TagmanagerV1::SetupTag

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tagmanager_v1/classes.rb,
lib/google/apis/tagmanager_v1/representations.rb,
lib/google/apis/tagmanager_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetupTag

Returns a new instance of SetupTag.



871
872
873
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 871

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stop_on_setup_failureBoolean Also known as: stop_on_setup_failure?

If true, fire the main tag if and only if the setup tag fires successfully. If false, fire the main tag regardless of setup tag firing status. Corresponds to the JSON property stopOnSetupFailure

Returns:

  • (Boolean)


863
864
865
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 863

def stop_on_setup_failure
  @stop_on_setup_failure
end

#tag_nameString

The name of the setup tag. Corresponds to the JSON property tagName

Returns:

  • (String)


869
870
871
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 869

def tag_name
  @tag_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



876
877
878
879
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 876

def update!(**args)
  @stop_on_setup_failure = args[:stop_on_setup_failure] if args.key?(:stop_on_setup_failure)
  @tag_name = args[:tag_name] if args.key?(:tag_name)
end