Class: Google::Apis::TagmanagerV1::Tag
- Inherits:
-
Object
- Object
- Google::Apis::TagmanagerV1::Tag
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tagmanager_v1/classes.rb,
lib/google/apis/tagmanager_v1/representations.rb,
lib/google/apis/tagmanager_v1/representations.rb
Overview
Represents a Google Tag Manager Tag.
Instance Attribute Summary collapse
-
#account_id ⇒ String
GTM Account ID.
-
#blocking_trigger_id ⇒ Array<String>
Blocking trigger IDs.
-
#container_id ⇒ String
GTM Container ID.
-
#fingerprint ⇒ String
The fingerprint of the GTM Tag as computed at storage time.
-
#firing_trigger_id ⇒ Array<String>
Firing trigger IDs.
-
#live_only ⇒ Boolean
(also: #live_only?)
If set to true, this tag will only fire in the live environment (e.g. not in preview or debug mode).
-
#name ⇒ String
Tag display name.
-
#notes ⇒ String
User notes on how to apply this tag in the container.
-
#parameter ⇒ Array<Google::Apis::TagmanagerV1::Parameter>
The tag's parameters.
-
#parent_folder_id ⇒ String
Parent folder id.
-
#paused ⇒ Boolean
(also: #paused?)
True if the tag is paused.
-
#priority ⇒ Google::Apis::TagmanagerV1::Parameter
Represents a Google Tag Manager Parameter.
-
#schedule_end_ms ⇒ Fixnum
The end timestamp in milliseconds to schedule a tag.
-
#schedule_start_ms ⇒ Fixnum
The start timestamp in milliseconds to schedule a tag.
-
#setup_tag ⇒ Array<Google::Apis::TagmanagerV1::SetupTag>
The list of setup tags.
-
#tag_firing_option ⇒ String
Option to fire this tag.
-
#tag_id ⇒ String
The Tag ID uniquely identifies the GTM Tag.
-
#teardown_tag ⇒ Array<Google::Apis::TagmanagerV1::TeardownTag>
The list of teardown tags.
-
#type ⇒ String
GTM Tag Type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Tag
constructor
A new instance of Tag.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Tag
Returns a new instance of Tag.
987 988 989 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 987 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ String
GTM Account ID.
Corresponds to the JSON property accountId
889 890 891 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 889 def account_id @account_id end |
#blocking_trigger_id ⇒ Array<String>
Blocking trigger IDs. If any of the listed triggers evaluate to true, the tag
will not fire.
Corresponds to the JSON property blockingTriggerId
895 896 897 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 895 def blocking_trigger_id @blocking_trigger_id end |
#container_id ⇒ String
GTM Container ID.
Corresponds to the JSON property containerId
900 901 902 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 900 def container_id @container_id end |
#fingerprint ⇒ String
The fingerprint of the GTM Tag as computed at storage time. This value is
recomputed whenever the tag is modified.
Corresponds to the JSON property fingerprint
906 907 908 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 906 def fingerprint @fingerprint end |
#firing_trigger_id ⇒ Array<String>
Firing trigger IDs. A tag will fire when any of the listed triggers are true
and all of its blockingTriggerIds (if any specified) are false.
Corresponds to the JSON property firingTriggerId
912 913 914 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 912 def firing_trigger_id @firing_trigger_id end |
#live_only ⇒ Boolean Also known as: live_only?
If set to true, this tag will only fire in the live environment (e.g. not in
preview or debug mode).
Corresponds to the JSON property liveOnly
918 919 920 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 918 def live_only @live_only end |
#name ⇒ String
Tag display name.
Corresponds to the JSON property name
924 925 926 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 924 def name @name end |
#notes ⇒ String
User notes on how to apply this tag in the container.
Corresponds to the JSON property notes
929 930 931 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 929 def notes @notes end |
#parameter ⇒ Array<Google::Apis::TagmanagerV1::Parameter>
The tag's parameters.
Corresponds to the JSON property parameter
934 935 936 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 934 def parameter @parameter end |
#parent_folder_id ⇒ String
Parent folder id.
Corresponds to the JSON property parentFolderId
939 940 941 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 939 def parent_folder_id @parent_folder_id end |
#paused ⇒ Boolean Also known as: paused?
True if the tag is paused.
Corresponds to the JSON property paused
944 945 946 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 944 def paused @paused end |
#priority ⇒ Google::Apis::TagmanagerV1::Parameter
Represents a Google Tag Manager Parameter.
Corresponds to the JSON property priority
950 951 952 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 950 def priority @priority end |
#schedule_end_ms ⇒ Fixnum
The end timestamp in milliseconds to schedule a tag.
Corresponds to the JSON property scheduleEndMs
955 956 957 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 955 def schedule_end_ms @schedule_end_ms end |
#schedule_start_ms ⇒ Fixnum
The start timestamp in milliseconds to schedule a tag.
Corresponds to the JSON property scheduleStartMs
960 961 962 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 960 def schedule_start_ms @schedule_start_ms end |
#setup_tag ⇒ Array<Google::Apis::TagmanagerV1::SetupTag>
The list of setup tags. Currently we only allow one.
Corresponds to the JSON property setupTag
965 966 967 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 965 def setup_tag @setup_tag end |
#tag_firing_option ⇒ String
Option to fire this tag.
Corresponds to the JSON property tagFiringOption
970 971 972 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 970 def tag_firing_option @tag_firing_option end |
#tag_id ⇒ String
The Tag ID uniquely identifies the GTM Tag.
Corresponds to the JSON property tagId
975 976 977 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 975 def tag_id @tag_id end |
#teardown_tag ⇒ Array<Google::Apis::TagmanagerV1::TeardownTag>
The list of teardown tags. Currently we only allow one.
Corresponds to the JSON property teardownTag
980 981 982 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 980 def teardown_tag @teardown_tag end |
#type ⇒ String
GTM Tag Type.
Corresponds to the JSON property type
985 986 987 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 985 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 992 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @blocking_trigger_id = args[:blocking_trigger_id] if args.key?(:blocking_trigger_id) @container_id = args[:container_id] if args.key?(:container_id) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @firing_trigger_id = args[:firing_trigger_id] if args.key?(:firing_trigger_id) @live_only = args[:live_only] if args.key?(:live_only) @name = args[:name] if args.key?(:name) @notes = args[:notes] if args.key?(:notes) @parameter = args[:parameter] if args.key?(:parameter) @parent_folder_id = args[:parent_folder_id] if args.key?(:parent_folder_id) @paused = args[:paused] if args.key?(:paused) @priority = args[:priority] if args.key?(:priority) @schedule_end_ms = args[:schedule_end_ms] if args.key?(:schedule_end_ms) @schedule_start_ms = args[:schedule_start_ms] if args.key?(:schedule_start_ms) @setup_tag = args[:setup_tag] if args.key?(:setup_tag) @tag_firing_option = args[:tag_firing_option] if args.key?(:tag_firing_option) @tag_id = args[:tag_id] if args.key?(:tag_id) @teardown_tag = args[:teardown_tag] if args.key?(:teardown_tag) @type = args[:type] if args.key?(:type) end |