Class: Google::Apis::TagmanagerV1::Trigger

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tagmanager_v1/classes.rb,
lib/google/apis/tagmanager_v1/representations.rb,
lib/google/apis/tagmanager_v1/representations.rb

Overview

Represents a Google Tag Manager Trigger

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Trigger

Returns a new instance of Trigger.



1187
1188
1189
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1187

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idString

GTM Account ID. Corresponds to the JSON property accountId

Returns:

  • (String)


1049
1050
1051
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1049

def 
  @account_id
end

#auto_event_filterArray<Google::Apis::TagmanagerV1::Condition>

Used in the case of auto event tracking. Corresponds to the JSON property autoEventFilter



1054
1055
1056
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1054

def auto_event_filter
  @auto_event_filter
end

#check_validationGoogle::Apis::TagmanagerV1::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property checkValidation



1059
1060
1061
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1059

def check_validation
  @check_validation
end

#container_idString

GTM Container ID. Corresponds to the JSON property containerId

Returns:

  • (String)


1064
1065
1066
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1064

def container_id
  @container_id
end

#continuous_time_min_millisecondsGoogle::Apis::TagmanagerV1::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property continuousTimeMinMilliseconds



1069
1070
1071
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1069

def continuous_time_min_milliseconds
  @continuous_time_min_milliseconds
end

#custom_event_filterArray<Google::Apis::TagmanagerV1::Condition>

Used in the case of custom event, which is fired iff all Conditions are true. Corresponds to the JSON property customEventFilter



1074
1075
1076
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1074

def custom_event_filter
  @custom_event_filter
end

#event_nameGoogle::Apis::TagmanagerV1::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property eventName



1079
1080
1081
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1079

def event_name
  @event_name
end

#filterArray<Google::Apis::TagmanagerV1::Condition>

The trigger will only fire iff all Conditions are true. Corresponds to the JSON property filter



1084
1085
1086
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1084

def filter
  @filter
end

#fingerprintString

The fingerprint of the GTM Trigger as computed at storage time. This value is recomputed whenever the trigger is modified. Corresponds to the JSON property fingerprint

Returns:

  • (String)


1090
1091
1092
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1090

def fingerprint
  @fingerprint
end

#horizontal_scroll_percentage_listGoogle::Apis::TagmanagerV1::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property horizontalScrollPercentageList



1095
1096
1097
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1095

def horizontal_scroll_percentage_list
  @horizontal_scroll_percentage_list
end

#intervalGoogle::Apis::TagmanagerV1::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property interval



1100
1101
1102
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1100

def interval
  @interval
end

#interval_secondsGoogle::Apis::TagmanagerV1::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property intervalSeconds



1105
1106
1107
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1105

def interval_seconds
  @interval_seconds
end

#limitGoogle::Apis::TagmanagerV1::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property limit



1110
1111
1112
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1110

def limit
  @limit
end

#max_timer_length_secondsGoogle::Apis::TagmanagerV1::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property maxTimerLengthSeconds



1115
1116
1117
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1115

def max_timer_length_seconds
  @max_timer_length_seconds
end

#nameString

Trigger display name. Corresponds to the JSON property name

Returns:

  • (String)


1120
1121
1122
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1120

def name
  @name
end

#parameterArray<Google::Apis::TagmanagerV1::Parameter>

Additional parameters. Corresponds to the JSON property parameter



1125
1126
1127
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1125

def parameter
  @parameter
end

#parent_folder_idString

Parent folder id. Corresponds to the JSON property parentFolderId

Returns:

  • (String)


1130
1131
1132
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1130

def parent_folder_id
  @parent_folder_id
end

#selectorGoogle::Apis::TagmanagerV1::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property selector



1135
1136
1137
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1135

def selector
  @selector
end

#total_time_min_millisecondsGoogle::Apis::TagmanagerV1::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property totalTimeMinMilliseconds



1140
1141
1142
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1140

def total_time_min_milliseconds
  @total_time_min_milliseconds
end

#trigger_idString

The Trigger ID uniquely identifies the GTM Trigger. Corresponds to the JSON property triggerId

Returns:

  • (String)


1145
1146
1147
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1145

def trigger_id
  @trigger_id
end

#typeString

Defines the data layer event that causes this trigger. Corresponds to the JSON property type

Returns:

  • (String)


1150
1151
1152
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1150

def type
  @type
end

#unique_trigger_idGoogle::Apis::TagmanagerV1::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property uniqueTriggerId



1155
1156
1157
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1155

def unique_trigger_id
  @unique_trigger_id
end

#vertical_scroll_percentage_listGoogle::Apis::TagmanagerV1::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property verticalScrollPercentageList



1160
1161
1162
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1160

def vertical_scroll_percentage_list
  @vertical_scroll_percentage_list
end

#visibility_selectorGoogle::Apis::TagmanagerV1::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property visibilitySelector



1165
1166
1167
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1165

def visibility_selector
  @visibility_selector
end

#visible_percentage_maxGoogle::Apis::TagmanagerV1::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property visiblePercentageMax



1170
1171
1172
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1170

def visible_percentage_max
  @visible_percentage_max
end

#visible_percentage_minGoogle::Apis::TagmanagerV1::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property visiblePercentageMin



1175
1176
1177
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1175

def visible_percentage_min
  @visible_percentage_min
end

#wait_for_tagsGoogle::Apis::TagmanagerV1::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property waitForTags



1180
1181
1182
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1180

def wait_for_tags
  @wait_for_tags
end

#wait_for_tags_timeoutGoogle::Apis::TagmanagerV1::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property waitForTagsTimeout



1185
1186
1187
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1185

def wait_for_tags_timeout
  @wait_for_tags_timeout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1192

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @auto_event_filter = args[:auto_event_filter] if args.key?(:auto_event_filter)
  @check_validation = args[:check_validation] if args.key?(:check_validation)
  @container_id = args[:container_id] if args.key?(:container_id)
  @continuous_time_min_milliseconds = args[:continuous_time_min_milliseconds] if args.key?(:continuous_time_min_milliseconds)
  @custom_event_filter = args[:custom_event_filter] if args.key?(:custom_event_filter)
  @event_name = args[:event_name] if args.key?(:event_name)
  @filter = args[:filter] if args.key?(:filter)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @horizontal_scroll_percentage_list = args[:horizontal_scroll_percentage_list] if args.key?(:horizontal_scroll_percentage_list)
  @interval = args[:interval] if args.key?(:interval)
  @interval_seconds = args[:interval_seconds] if args.key?(:interval_seconds)
  @limit = args[:limit] if args.key?(:limit)
  @max_timer_length_seconds = args[:max_timer_length_seconds] if args.key?(:max_timer_length_seconds)
  @name = args[:name] if args.key?(:name)
  @parameter = args[:parameter] if args.key?(:parameter)
  @parent_folder_id = args[:parent_folder_id] if args.key?(:parent_folder_id)
  @selector = args[:selector] if args.key?(:selector)
  @total_time_min_milliseconds = args[:total_time_min_milliseconds] if args.key?(:total_time_min_milliseconds)
  @trigger_id = args[:trigger_id] if args.key?(:trigger_id)
  @type = args[:type] if args.key?(:type)
  @unique_trigger_id = args[:unique_trigger_id] if args.key?(:unique_trigger_id)
  @vertical_scroll_percentage_list = args[:vertical_scroll_percentage_list] if args.key?(:vertical_scroll_percentage_list)
  @visibility_selector = args[:visibility_selector] if args.key?(:visibility_selector)
  @visible_percentage_max = args[:visible_percentage_max] if args.key?(:visible_percentage_max)
  @visible_percentage_min = args[:visible_percentage_min] if args.key?(:visible_percentage_min)
  @wait_for_tags = args[:wait_for_tags] if args.key?(:wait_for_tags)
  @wait_for_tags_timeout = args[:wait_for_tags_timeout] if args.key?(:wait_for_tags_timeout)
end