Class: Google::Apis::TagmanagerV1::ContainerVersion
- Inherits:
-
Object
- Object
- Google::Apis::TagmanagerV1::ContainerVersion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tagmanager_v1/classes.rb,
lib/google/apis/tagmanager_v1/representations.rb,
lib/google/apis/tagmanager_v1/representations.rb
Overview
Represents a Google Tag Manager Container Version.
Instance Attribute Summary collapse
-
#account_id ⇒ String
GTM Account ID.
-
#container ⇒ Google::Apis::TagmanagerV1::Container
Represents a Google Tag Manager Container.
-
#container_id ⇒ String
GTM Container ID.
-
#container_version_id ⇒ String
The Container Version ID uniquely identifies the GTM Container Version.
-
#deleted ⇒ Boolean
(also: #deleted?)
A value of true indicates this container version has been deleted.
-
#fingerprint ⇒ String
The fingerprint of the GTM Container Version as computed at storage time.
-
#folder ⇒ Array<Google::Apis::TagmanagerV1::Folder>
The folders in the container that this version was taken from.
-
#name ⇒ String
Container version display name.
-
#notes ⇒ String
User notes on how to apply this container version in the container.
-
#tag ⇒ Array<Google::Apis::TagmanagerV1::Tag>
The tags in the container that this version was taken from.
-
#trigger ⇒ Array<Google::Apis::TagmanagerV1::Trigger>
The triggers in the container that this version was taken from.
-
#variable ⇒ Array<Google::Apis::TagmanagerV1::Variable>
The variables in the container that this version was taken from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContainerVersion
constructor
A new instance of ContainerVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContainerVersion
Returns a new instance of ContainerVersion.
293 294 295 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 293 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ String
GTM Account ID.
Corresponds to the JSON property accountId
234 235 236 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 234 def account_id @account_id end |
#container ⇒ Google::Apis::TagmanagerV1::Container
Represents a Google Tag Manager Container.
Corresponds to the JSON property container
239 240 241 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 239 def container @container end |
#container_id ⇒ String
GTM Container ID.
Corresponds to the JSON property containerId
244 245 246 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 244 def container_id @container_id end |
#container_version_id ⇒ String
The Container Version ID uniquely identifies the GTM Container Version.
Corresponds to the JSON property containerVersionId
249 250 251 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 249 def container_version_id @container_version_id end |
#deleted ⇒ Boolean Also known as: deleted?
A value of true indicates this container version has been deleted.
Corresponds to the JSON property deleted
254 255 256 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 254 def deleted @deleted end |
#fingerprint ⇒ String
The fingerprint of the GTM Container Version as computed at storage time. This
value is recomputed whenever the container version is modified.
Corresponds to the JSON property fingerprint
261 262 263 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 261 def fingerprint @fingerprint end |
#folder ⇒ Array<Google::Apis::TagmanagerV1::Folder>
The folders in the container that this version was taken from.
Corresponds to the JSON property folder
266 267 268 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 266 def folder @folder end |
#name ⇒ String
Container version display name.
Corresponds to the JSON property name
271 272 273 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 271 def name @name end |
#notes ⇒ String
User notes on how to apply this container version in the container.
Corresponds to the JSON property notes
276 277 278 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 276 def notes @notes end |
#tag ⇒ Array<Google::Apis::TagmanagerV1::Tag>
The tags in the container that this version was taken from.
Corresponds to the JSON property tag
281 282 283 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 281 def tag @tag end |
#trigger ⇒ Array<Google::Apis::TagmanagerV1::Trigger>
The triggers in the container that this version was taken from.
Corresponds to the JSON property trigger
286 287 288 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 286 def trigger @trigger end |
#variable ⇒ Array<Google::Apis::TagmanagerV1::Variable>
The variables in the container that this version was taken from.
Corresponds to the JSON property variable
291 292 293 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 291 def variable @variable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
298 299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 298 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @container = args[:container] if args.key?(:container) @container_id = args[:container_id] if args.key?(:container_id) @container_version_id = args[:container_version_id] if args.key?(:container_version_id) @deleted = args[:deleted] if args.key?(:deleted) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @folder = args[:folder] if args.key?(:folder) @name = args[:name] if args.key?(:name) @notes = args[:notes] if args.key?(:notes) @tag = args[:tag] if args.key?(:tag) @trigger = args[:trigger] if args.key?(:trigger) @variable = args[:variable] if args.key?(:variable) end |