Class: Google::Apis::TagmanagerV1::TeardownTag
- Inherits:
-
Object
- Object
- Google::Apis::TagmanagerV1::TeardownTag
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tagmanager_v1/classes.rb,
lib/google/apis/tagmanager_v1/representations.rb,
lib/google/apis/tagmanager_v1/representations.rb
Instance Attribute Summary collapse
-
#stop_teardown_on_failure ⇒ Boolean
(also: #stop_teardown_on_failure?)
If true, fire the teardown tag if and only if the main tag fires successfully.
-
#tag_name ⇒ String
The name of the teardown tag.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TeardownTag
constructor
A new instance of TeardownTag.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TeardownTag
Returns a new instance of TeardownTag.
1031 1032 1033 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1031 def initialize(**args) update!(**args) end |
Instance Attribute Details
#stop_teardown_on_failure ⇒ Boolean Also known as: stop_teardown_on_failure?
If true, fire the teardown tag if and only if the main tag fires successfully.
If false, fire the teardown tag regardless of main tag firing status.
Corresponds to the JSON property stopTeardownOnFailure
1023 1024 1025 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1023 def stop_teardown_on_failure @stop_teardown_on_failure end |
#tag_name ⇒ String
The name of the teardown tag.
Corresponds to the JSON property tagName
1029 1030 1031 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1029 def tag_name @tag_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1036 1037 1038 1039 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1036 def update!(**args) @stop_teardown_on_failure = args[:stop_teardown_on_failure] if args.key?(:stop_teardown_on_failure) @tag_name = args[:tag_name] if args.key?(:tag_name) end |