Class: Google::Apis::TagmanagerV1::Variable
- Inherits:
-
Object
- Object
- Google::Apis::TagmanagerV1::Variable
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tagmanager_v1/classes.rb,
lib/google/apis/tagmanager_v1/representations.rb,
lib/google/apis/tagmanager_v1/representations.rb
Overview
Represents a Google Tag Manager Variable.
Instance Attribute Summary collapse
-
#account_id ⇒ String
GTM Account ID.
-
#container_id ⇒ String
GTM Container ID.
-
#disabling_trigger_id ⇒ Array<String>
For mobile containers only: A list of trigger IDs for disabling conditional variables; the variable is enabled if one of the enabling trigger is true while all the disabling trigger are false.
-
#enabling_trigger_id ⇒ Array<String>
For mobile containers only: A list of trigger IDs for enabling conditional variables; the variable is enabled if one of the enabling triggers is true while all the disabling triggers are false.
-
#fingerprint ⇒ String
The fingerprint of the GTM Variable as computed at storage time.
-
#name ⇒ String
Variable display name.
-
#notes ⇒ String
User notes on how to apply this variable in the container.
-
#parameter ⇒ Array<Google::Apis::TagmanagerV1::Parameter>
The variable's parameters.
-
#parent_folder_id ⇒ String
Parent folder id.
-
#schedule_end_ms ⇒ Fixnum
The end timestamp in milliseconds to schedule a variable.
-
#schedule_start_ms ⇒ Fixnum
The start timestamp in milliseconds to schedule a variable.
-
#type ⇒ String
GTM Variable Type.
-
#variable_id ⇒ String
The Variable ID uniquely identifies the GTM Variable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Variable
constructor
A new instance of Variable.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Variable
Returns a new instance of Variable.
1341 1342 1343 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1341 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ String
GTM Account ID.
Corresponds to the JSON property accountId
1274 1275 1276 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1274 def account_id @account_id end |
#container_id ⇒ String
GTM Container ID.
Corresponds to the JSON property containerId
1279 1280 1281 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1279 def container_id @container_id end |
#disabling_trigger_id ⇒ Array<String>
For mobile containers only: A list of trigger IDs for disabling conditional
variables; the variable is enabled if one of the enabling trigger is true
while all the disabling trigger are false. Treated as an unordered set.
Corresponds to the JSON property disablingTriggerId
1286 1287 1288 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1286 def disabling_trigger_id @disabling_trigger_id end |
#enabling_trigger_id ⇒ Array<String>
For mobile containers only: A list of trigger IDs for enabling conditional
variables; the variable is enabled if one of the enabling triggers is true
while all the disabling triggers are false. Treated as an unordered set.
Corresponds to the JSON property enablingTriggerId
1293 1294 1295 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1293 def enabling_trigger_id @enabling_trigger_id end |
#fingerprint ⇒ String
The fingerprint of the GTM Variable as computed at storage time. This value is
recomputed whenever the variable is modified.
Corresponds to the JSON property fingerprint
1299 1300 1301 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1299 def fingerprint @fingerprint end |
#name ⇒ String
Variable display name.
Corresponds to the JSON property name
1304 1305 1306 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1304 def name @name end |
#notes ⇒ String
User notes on how to apply this variable in the container.
Corresponds to the JSON property notes
1309 1310 1311 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1309 def notes @notes end |
#parameter ⇒ Array<Google::Apis::TagmanagerV1::Parameter>
The variable's parameters.
Corresponds to the JSON property parameter
1314 1315 1316 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1314 def parameter @parameter end |
#parent_folder_id ⇒ String
Parent folder id.
Corresponds to the JSON property parentFolderId
1319 1320 1321 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1319 def parent_folder_id @parent_folder_id end |
#schedule_end_ms ⇒ Fixnum
The end timestamp in milliseconds to schedule a variable.
Corresponds to the JSON property scheduleEndMs
1324 1325 1326 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1324 def schedule_end_ms @schedule_end_ms end |
#schedule_start_ms ⇒ Fixnum
The start timestamp in milliseconds to schedule a variable.
Corresponds to the JSON property scheduleStartMs
1329 1330 1331 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1329 def schedule_start_ms @schedule_start_ms end |
#type ⇒ String
GTM Variable Type.
Corresponds to the JSON property type
1334 1335 1336 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1334 def type @type end |
#variable_id ⇒ String
The Variable ID uniquely identifies the GTM Variable.
Corresponds to the JSON property variableId
1339 1340 1341 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1339 def variable_id @variable_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 |
# File 'lib/google/apis/tagmanager_v1/classes.rb', line 1346 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @container_id = args[:container_id] if args.key?(:container_id) @disabling_trigger_id = args[:disabling_trigger_id] if args.key?(:disabling_trigger_id) @enabling_trigger_id = args[:enabling_trigger_id] if args.key?(:enabling_trigger_id) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @name = args[:name] if args.key?(:name) @notes = args[:notes] if args.key?(:notes) @parameter = args[:parameter] if args.key?(:parameter) @parent_folder_id = args[:parent_folder_id] if args.key?(:parent_folder_id) @schedule_end_ms = args[:schedule_end_ms] if args.key?(:schedule_end_ms) @schedule_start_ms = args[:schedule_start_ms] if args.key?(:schedule_start_ms) @type = args[:type] if args.key?(:type) @variable_id = args[:variable_id] if args.key?(:variable_id) end |